pascual » home

# PAScual Home Page

## Description

This is the home page for PAScual, a Free/Open Source program for analysing data from Positron Annihilation Lifetime Spectroscopy (PALS) written by Carlos Pascual-Izarra

##

## Tips

You can download (for free) the latest stable version of PAScual here.
The latest development version (which might not be suitable for production) is also available via a Subversion server.
For instructions on installation and use of PAScual, refer to the User Manual
If you intend to use PAScual, consider joining the PAScual-Info mailing list. It is a low-traffic announcements-only list that will keep you aware of new version releases.
For extra documentation (like preprints, posters, etc)... check the Documentation section.

## Contact

If you need help or have comments/suggestions, you can contact the author.